clear
clc
s = zpk('s'); 
%% plant transfer function
plant = [tf([-1.87],[107.5 1]) tf([1.87],[79.4 1]) ; 
tf([0.88],[185 1]) tf([0.88],[185 1])];
 
%% uncertainty weighting function
k11 = 10^(-0.67/20);
k22 = 10^(-1.2/20); 
a = 0.007;
b = a / (k22 / k11);
 
W = 1*[k11 * tf([1 a],[1 b]) 0 ; 
0 k11 * tf([1 a],[1 b])];

%% performance weighting function
Ws = 0.75*[(1)*(s + 0.005)/(s + 5e-6) 0;...
     0 (1)*(s + 0.001)/(s + 5e-6)];
 
%% Actuator effort weighting function
Wu = [9 0 ; 0 9];
 
%%  Now that the plant and the weight have been defined
systemnames =  'plant W Wu Ws';
inputvar    =  '[yd{2} ; u{2}]';
outputvar   =  '[W ; Ws ; Wu ; yd - plant]';
input_to_plant =  '[u]';
input_to_W =  '[plant]';
input_to_Wu =  '[u]';
input_to_Ws =  '[yd - plant]';
sysoutname =   'G_hinf';
cleanupsysic = 'yes';
sysic
G_hinf = minreal(G_hinf);

nmeas = 2;
ncon = 2;
nz2 = 2;
h2max = 1;
alpha = .8; 
beta  = .2; 
wz = [alpha beta]; 
[k1,g1,normz1,info1] = h2hinfsyn(ss(G_hinf),nmeas,ncon,nz2,wz,...
    'Display','on','h2max',h2max,'hinfmax',inf);

clp_h2hinf=g1;
k1_h2hinf=k1;
omega = logspace(-3,2,200);
g1=tf(g1);
sig_g1=sigma(g1,omega);
semilogx(omega,sig_g1(1,:),'b')
hold on
T=[g1(1,1) g1(1,2);g1(2,1) g1(2,2)];
sig_T=sigma(T,omega);
semilogx(omega,sig_T(1,:),'r')
hold on
S=[g1(3,1) g1(3,2);g1(4,1) g1(4,2)];
sig_S=sigma(S,omega);
semilogx(omega,sig_S(1,:),'g')
hold on
U=[g1(5,1) g1(5,2);g1(6,1) g1(6,2)];
sig_U=sigma(U,omega);
semilogx(omega,sig_U(1,:),'k')

grid off
d=legend('\sigma_{max}','WT','W_sS','W_uU')
xlabel('Frequency (rad/s)')

set(d,'FontSize',12)
%figure
m=get(d,'parent')
%axes
n=get(m,'CurrentAxes')
set(n,'FontSize',12,'XLim',[0.01 1e+02])
xlabel('Frequency (rad/s)')
%line
k=get(n,'Children')
set(k(1),'LineWidth',2)
set(k(2),'LineWidth',2)
set(k(3),'LineWidth',2)
set(k(4),'LineWidth',2)

gtext('\sigma_{max}')
gtext('WT')
gtext('W_sS')
gtext('W_uU')
% 
% 
[k1_red,info2] = reduce(k1,6);
omega = logspace(-3,3,200); 
sv1 = sigma(k1,omega);
sv2 = sigma(k1_red,omega);
 
subplot(2,1,1);
plot(omega,20*log10(sv1(1,:)),'linewidth',2);hold on;
plot(omega,20*log10(sv2(1,:)),'--r','linewidth',2);
legend('max sv for k1','max sv for k1_{reduced}');grid on
 
subplot(2,1,2);
plot(omega,20*log10(sv1(2,:)),'linewidth',2);hold on;
plot(omega,20*log10(sv2(2,:)),'--r','linewidth',2);
legend('min sv for k1','min sv for k1_{reduced}');grid on